@@ -2,10 +2,10 @@ Combination <- function(finalX,finalY_train,Cell,finalY_train_cell,n_tree,m_feat
 
   Serial=NULL
   for (p in length(Cell):1){
-    nk=combs(1:length(Cell),p)
+    nk=combn(1:length(Cell),p)
     sk=length(Serial)
-    for (q in 1:dim(nk)[1]){
-      Serial[[sk+q]]=nk[q, ]
+    for (q in 1:dim(nk)[2]){
+      Serial[[sk+q]]=nk[ ,q]
     }
   }
   ##
